diff mbox

[Branch,~linaro-validation/lava-dashboard/trunk] Rev 231: Use lava-dev-tool in setup-dev-env.sh

Message ID 20110626091539.17606.85356.launchpad@loganberry.canonical.com
State Accepted
Headers show

Commit Message

Zygmunt Krynicki June 26, 2011, 9:15 a.m. UTC
------------------------------------------------------------
revno: 231
committer: Zygmunt Krynicki <zygmunt.krynicki@linaro.org>
branch nick: trunk
timestamp: Sun 2011-06-26 11:13:57 +0200
message:
  Use lava-dev-tool in setup-dev-env.sh
modified:
  setup-dev-env.sh


--
lp:lava-dashboard
https://code.launchpad.net/~linaro-validation/lava-dashboard/trunk

You are subscribed to branch lp:lava-dashboard.
To unsubscribe from this branch go to https://code.launchpad.net/~linaro-validation/lava-dashboard/trunk/+edit-subscription
diff mbox

Patch

=== modified file 'setup-dev-env.sh'
--- setup-dev-env.sh	2011-06-06 09:29:08 +0000
+++ setup-dev-env.sh	2011-06-26 09:13:57 +0000
@@ -11,7 +11,7 @@ 
         PORT=8000
     fi
 fi
 # Setup dashboard URL for lc-tool
 export DASHBOARD_URL=http://localhost:$PORT/dashboard
 # Find root directory
 ROOT="$(bzr root)"
@@ -69,18 +69,18 @@ 
     echo " * waiting for server to start up"
     sleep 5
     echo " * creating bundle stream for example data" 
-    lc-tool make-stream /anonymous/examples/ --name "Demo content loaded from examples/bundles"
+    lava-dashboard-tool make-stream /anonymous/examples/ --name "Demo content loaded from examples/bundles"
     for BUNDLE_PATHNAME in $ROOT/examples/bundles/*.json; do
         BUNDLE=$(basename $BUNDLE_PATHNAME .json)
         echo " * importing bundle: $BUNDLE"
-        lc-tool put $BUNDLE_PATHNAME >/dev/null
+        lava-dashboard-tool put $BUNDLE_PATHNAME >/dev/null
     done
     for BUNDLE_PATHNAME in $ROOT/examples/bundles/templates/*.json; do
         BUNDLE=$(basename $BUNDLE_PATHNAME .json)
         echo " * importing bundle template: $BUNDLE"
         for i in $(seq 1 20); do
             sed "$BUNDLE_PATHNAME" -e "s!@TEMPLATE@!$(printf %04d $i)!g" > "$i-$BUNDLE"
-            lc-tool put "$i-$BUNDLE" /anonymous/examples/ >/dev/null
+            lava-dashboard-tool put "$i-$BUNDLE" /anonymous/examples/ >/dev/null
             rm -f "$i-$BUNDLE"
         done
     done
@@ -11,7 +11,7 @@ 
     fi
 fi
-# Setup dashboard URL for lc-tool
+# Setup dashboard URL for lava-dashboard-tool
 export DASHBOARD_URL=http://localhost:$PORT/dashboard
 # Find root directory